# gera2ld.pyserve

Start serving an asyncio.Server, and show information for development.

## Installation

```sh
$ pip install gera2ld-pyserve
```

## Usage

```py
from gera2ld.pyserve import serve_forever

serve_forever(server)
```
